[pypy-commit] lang-smalltalk storage-cleanups: Fixed -A flag to execute very slow tests.

anton_gulenko noreply at buildbot.pypy.org
Thu Aug 21 12:55:01 CEST 2014


Author: Anton Gulenko <anton.gulenko at googlemail.com>
Branch: storage-cleanups
Changeset: r1039:038a4928d7ac
Date: 2014-08-20 16:48 +0200
http://bitbucket.org/pypy/lang-smalltalk/changeset/038a4928d7ac/

Log:	Fixed -A flag to execute very slow tests.

diff --git a/spyvm/test/util.py b/spyvm/test/util.py
--- a/spyvm/test/util.py
+++ b/spyvm/test/util.py
@@ -6,7 +6,8 @@
 # The according options is configured in conftest.py.
 # To mark all tests in a module as slow, add this line to the module:
 # pytestmark = slow_test
-slow_test = py.test.mark.skipif('not config.getvalue("execute-slow-tests") or config.getvalue("execute-all-tests")',
+slow_test = py.test.mark.skipif('    not config.getvalue("execute-slow-tests")' +
+                                'and not config.getvalue("execute-all-tests")',
                         reason="Slow tests are being skipped. Add --slow|-S to execute slow tests.")
 
 very_slow_test = py.test.mark.skipif('not config.getvalue("execute-all-tests")',


More information about the pypy-commit mailing list
diff --git a/spyvm/test/conftest.py b/spyvm/test/conftest.py
--- a/spyvm/test/conftest.py
+++ b/spyvm/test/conftest.py
@@ -21,10 +21,10 @@
         dest="rsqueak-binary",
         action="store",
         default=None,
-        help="Path to a compiled rsqueak binary"
+        help="Path to a compiled rsqueak binary. Enables jit tests."
     )
 
 # The 'spy' parameter is used in tests under jittest/
 def pytest_funcarg__spy(request):
     val = request.config.getvalue("rsqueak-binary")
     if not val:
@@ -21,10 +21,10 @@
     )
 
-# The 'spy' parameter is used in tests under jittest/
+# The 'jit' parameter is used in tests under jittest/
 def pytest_funcarg__spy(request):
     val = request.config.getvalue("rsqueak-binary")